==> xerces25_2.5.0.orig.tar.gz: xerces-c-src_2_5_0/src/xercesc/dom/deprecated/AttrMapImpl.hpp <==
#ifndef AttrMapImpl_HEADER_GUARD_
#define AttrMapImpl_HEADER_GUARD_

/*
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 1999-2002 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Xerces" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache\@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation, and was
 * originally based on software copyright (c) 1999, International
 * Business Machines, Inc., http://www.ibm.com .  For more information
 * on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

//
//  This file is part of the internal implementation of the C++ XML DOM.
//  It should NOT be included or used directly by application programs.
//
//  Applications should include the file <xercesc/dom/deprecated/DOM.hpp> for the entire
//  DOM API, or DOM_*.hpp for individual DOM classes, where the class
//  name is substituded for the *.
//

/*
 * $Id: AttrMapImpl.hpp,v 1.3 2002/11/04 15:04:44 tng Exp $
 */

#include <xercesc/util/XercesDefs.hpp>
#include "AttrImpl.hpp"
#include "NodeImpl.hpp"
#include "NamedNodeMapImpl.hpp"

XERCES_CPP_NAMESPACE_BEGIN


class NamedNodeMapImpl;

class CDOM_EXPORT AttrMapImpl : public NamedNodeMapImpl
{
private:
	bool attrDefaults;

public:
	AttrMapImpl(NodeImpl *ownerNod);
	AttrMapImpl(NodeImpl *ownerNod, NamedNodeMapImpl *defaults);
	virtual ~AttrMapImpl();
	virtual AttrMapImpl *cloneAttrMap(NodeImpl *ownerNode);
	virtual bool hasDefaults();
	virtual void hasDefaults(bool value);

    virtual NodeImpl *removeNamedItem(const DOMString &name);
    virtual NodeImpl *removeNamedItemNS(const DOMString &namespaceURI, const DOMString &localName);
};

// ---------------------------------------------------------------------------
//  AttrMapImpl: Getters & Setters
// ---------------------------------------------------------------------------

inline bool AttrMapImpl::hasDefaults()
{
	return attrDefaults;
}

inline void AttrMapImpl::hasDefaults(bool value)
{
	attrDefaults = value;
}


XERCES_CPP_NAMESPACE_END

#endif

==> xerces26_2.6.0.orig.tar.gz: xerces-c-src_2_6_0/src/xercesc/dom/deprecated/AttrMapImpl.hpp <==
#ifndef AttrMapImpl_HEADER_GUARD_
#define AttrMapImpl_HEADER_GUARD_

/*
 * Copyright 1999-2002,2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

//
//  This file is part of the internal implementation of the C++ XML DOM.
//  It should NOT be included or used directly by application programs.
//
//  Applications should include the file <xercesc/dom/deprecated/DOM.hpp> for the entire
//  DOM API, or DOM_*.hpp for individual DOM classes, where the class
//  name is substituded for the *.
//

/*
 * $Id: AttrMapImpl.hpp,v 1.5 2004/09/08 13:55:42 peiyongz Exp $
 */

#include <xercesc/util/XercesDefs.hpp>
#include "AttrImpl.hpp"
#include "NodeImpl.hpp"
#include "NamedNodeMapImpl.hpp"

XERCES_CPP_NAMESPACE_BEGIN


class NamedNodeMapImpl;

class DEPRECATED_DOM_EXPORT AttrMapImpl : public NamedNodeMapImpl
{
private:
	bool attrDefaults;

public:
	AttrMapImpl(NodeImpl *ownerNod);
	AttrMapImpl(NodeImpl *ownerNod, NamedNodeMapImpl *defaults);
	virtual ~AttrMapImpl();
	virtual AttrMapImpl *cloneAttrMap(NodeImpl *ownerNode);
	virtual bool hasDefaults();
	virtual void hasDefaults(bool value);

    virtual NodeImpl *removeNamedItem(const DOMString &name);
    virtual NodeImpl *removeNamedItemNS(const DOMString &namespaceURI, const DOMString &localName);
};

// ---------------------------------------------------------------------------
//  AttrMapImpl: Getters & Setters
// ---------------------------------------------------------------------------

inline bool AttrMapImpl::hasDefaults()
{
	return attrDefaults;
}

inline void AttrMapImpl::hasDefaults(bool value)
{
	attrDefaults = value;
}


XERCES_CPP_NAMESPACE_END

#endif
